# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class SettingsRequest(BaseModel):
    """
    Settings Serializer
    """ # noqa: E501
    avatars: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Configure how authentik should show avatars for users.")
    default_user_change_name: Optional[StrictBool] = Field(default=None, description="Enable the ability for users to change their name.")
    default_user_change_email: Optional[StrictBool] = Field(default=None, description="Enable the ability for users to change their email address.")
    default_user_change_username: Optional[StrictBool] = Field(default=None, description="Enable the ability for users to change their username.")
    event_retention: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Events will be deleted after this duration.(Format: weeks=3;days=2;hours=3,seconds=2).")
    footer_links: Optional[Any] = Field(default=None, description="The option configures the footer links on the flow executor pages.")
    gdpr_compliance: Optional[StrictBool] = Field(default=None, description="When enabled, all the events caused by a user will be deleted upon the user's deletion.")
    impersonation: Optional[StrictBool] = Field(default=None, description="Globally enable/disable impersonation.")
    impersonation_require_reason: Optional[StrictBool] = Field(default=None, description="Require administrators to provide a reason for impersonating a user.")
    default_token_duration: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Default token duration")
    default_token_length: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=1)]] = Field(default=None, description="Default token length")
    __properties: ClassVar[List[str]] = ["avatars", "default_user_change_name", "default_user_change_email", "default_user_change_username", "event_retention", "footer_links", "gdpr_compliance", "impersonation", "impersonation_require_reason", "default_token_duration", "default_token_length"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SettingsRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if footer_links (nullable) is None
        # and model_fields_set contains the field
        if self.footer_links is None and "footer_links" in self.model_fields_set:
            _dict['footer_links'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SettingsRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "avatars": obj.get("avatars"),
            "default_user_change_name": obj.get("default_user_change_name"),
            "default_user_change_email": obj.get("default_user_change_email"),
            "default_user_change_username": obj.get("default_user_change_username"),
            "event_retention": obj.get("event_retention"),
            "footer_links": obj.get("footer_links"),
            "gdpr_compliance": obj.get("gdpr_compliance"),
            "impersonation": obj.get("impersonation"),
            "impersonation_require_reason": obj.get("impersonation_require_reason"),
            "default_token_duration": obj.get("default_token_duration"),
            "default_token_length": obj.get("default_token_length")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from authentik_client.models.proxy_mode import ProxyMode
from typing import Optional, Set
from typing_extensions import Self

class ProxyProviderRequest(BaseModel):
    """
    ProxyProvider Serializer
    """ # noqa: E501
    name: Annotated[str, Field(min_length=1, strict=True)]
    authentication_flow: Optional[StrictStr] = Field(default=None, description="Flow used for authentication when the associated application is accessed by an un-authenticated user.")
    authorization_flow: StrictStr = Field(description="Flow used when authorizing this provider.")
    invalidation_flow: StrictStr = Field(description="Flow used ending the session from a provider.")
    property_mappings: Optional[List[StrictStr]] = None
    internal_host: Optional[StrictStr] = None
    external_host: Annotated[str, Field(min_length=1, strict=True)]
    internal_host_ssl_validation: Optional[StrictBool] = Field(default=None, description="Validate SSL Certificates of upstream servers")
    certificate: Optional[StrictStr] = None
    skip_path_regex: Optional[StrictStr] = Field(default=None, description="Regular expressions for which authentication is not required. Each new line is interpreted as a new Regular Expression.")
    basic_auth_enabled: Optional[StrictBool] = Field(default=None, description="Set a custom HTTP-Basic Authentication header based on values from authentik.")
    basic_auth_password_attribute: Optional[StrictStr] = Field(default=None, description="User/Group Attribute used for the password part of the HTTP-Basic Header.")
    basic_auth_user_attribute: Optional[StrictStr] = Field(default=None, description="User/Group Attribute used for the user part of the HTTP-Basic Header. If not set, the user's Email address is used.")
    mode: Optional[ProxyMode] = Field(default=None, description="Enable support for forwardAuth in traefik and nginx auth_request. Exclusive with internal_host.")
    intercept_header_auth: Optional[StrictBool] = Field(default=None, description="When enabled, this provider will intercept the authorization header and authenticate requests based on its value.")
    cookie_domain: Optional[StrictStr] = None
    jwt_federation_sources: Optional[List[StrictStr]] = None
    jwt_federation_providers: Optional[List[StrictInt]] = None
    access_token_validity: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).")
    refresh_token_validity: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).")
    __properties: ClassVar[List[str]] = ["name", "authentication_flow", "authorization_flow", "invalidation_flow", "property_mappings", "internal_host", "external_host", "internal_host_ssl_validation", "certificate", "skip_path_regex", "basic_auth_enabled", "basic_auth_password_attribute", "basic_auth_user_attribute", "mode", "intercept_header_auth", "cookie_domain", "jwt_federation_sources", "jwt_federation_providers", "access_token_validity", "refresh_token_validity"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProxyProviderRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if authentication_flow (nullable) is None
        # and model_fields_set contains the field
        if self.authentication_flow is None and "authentication_flow" in self.model_fields_set:
            _dict['authentication_flow'] = None

        # set to None if certificate (nullable) is None
        # and model_fields_set contains the field
        if self.certificate is None and "certificate" in self.model_fields_set:
            _dict['certificate'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProxyProviderRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "authentication_flow": obj.get("authentication_flow"),
            "authorization_flow": obj.get("authorization_flow"),
            "invalidation_flow": obj.get("invalidation_flow"),
            "property_mappings": obj.get("property_mappings"),
            "internal_host": obj.get("internal_host"),
            "external_host": obj.get("external_host"),
            "internal_host_ssl_validation": obj.get("internal_host_ssl_validation"),
            "certificate": obj.get("certificate"),
            "skip_path_regex": obj.get("skip_path_regex"),
            "basic_auth_enabled": obj.get("basic_auth_enabled"),
            "basic_auth_password_attribute": obj.get("basic_auth_password_attribute"),
            "basic_auth_user_attribute": obj.get("basic_auth_user_attribute"),
            "mode": obj.get("mode"),
            "intercept_header_auth": obj.get("intercept_header_auth"),
            "cookie_domain": obj.get("cookie_domain"),
            "jwt_federation_sources": obj.get("jwt_federation_sources"),
            "jwt_federation_providers": obj.get("jwt_federation_providers"),
            "access_token_validity": obj.get("access_token_validity"),
            "refresh_token_validity": obj.get("refresh_token_validity")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.blueprint_instance import BlueprintInstance

class TestBlueprintInstance(unittest.TestCase):
    """BlueprintInstance unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BlueprintInstance:
        """Test BlueprintInstance
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BlueprintInstance`
        """
        model = BlueprintInstance()
        if include_optional:
            return BlueprintInstance(
                pk = '',
                name = '',
                path = '',
                context = None,
                last_applied = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                last_applied_hash = '',
                status = 'successful',
                enabled = True,
                managed_models = [
                    ''
                    ],
                metadata = None,
                content = ''
            )
        else:
            return BlueprintInstance(
                pk = '',
                name = '',
                last_applied = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                last_applied_hash = '',
                status = 'successful',
                managed_models = [
                    ''
                    ],
                metadata = None,
        )
        """

    def testBlueprintInstance(self):
        """Test BlueprintInstance"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.brand import Brand

class TestBrand(unittest.TestCase):
    """Brand unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Brand:
        """Test Brand
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Brand`
        """
        model = Brand()
        if include_optional:
            return Brand(
                brand_uuid = '',
                domain = '',
                default = True,
                branding_title = '',
                branding_logo = '',
                branding_favicon = '',
                flow_authentication = '',
                flow_invalidation = '',
                flow_recovery = '',
                flow_unenrollment = '',
                flow_user_settings = '',
                flow_device_code = '',
                default_application = '',
                web_certificate = '',
                attributes = None
            )
        else:
            return Brand(
                brand_uuid = '',
                domain = '',
        )
        """

    def testBrand(self):
        """Test Brand"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class DigestAlgorithmEnum(str, Enum):
    """
    DigestAlgorithmEnum
    """

    """
    allowed enum values
    """
    HTTP_COLON_SLASH_SLASH_WWW_DOT_W3_DOT_ORG_SLASH_2000_SLASH_09_SLASH_XMLDSIG_HASH_SHA1 = 'http://www.w3.org/2000/09/xmldsig#sha1'
    HTTP_COLON_SLASH_SLASH_WWW_DOT_W3_DOT_ORG_SLASH_2001_SLASH_04_SLASH_XMLENC_HASH_SHA256 = 'http://www.w3.org/2001/04/xmlenc#sha256'
    HTTP_COLON_SLASH_SLASH_WWW_DOT_W3_DOT_ORG_SLASH_2001_SLASH_04_SLASH_XMLDSIG_MINUS_MORE_HASH_SHA384 = 'http://www.w3.org/2001/04/xmldsig-more#sha384'
    HTTP_COLON_SLASH_SLASH_WWW_DOT_W3_DOT_ORG_SLASH_2001_SLASH_04_SLASH_XMLENC_HASH_SHA512 = 'http://www.w3.org/2001/04/xmlenc#sha512'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DigestAlgorithmEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from authentik_client.models.client_type_enum import ClientTypeEnum
from authentik_client.models.issuer_mode_enum import IssuerModeEnum
from authentik_client.models.redirect_uri_request import RedirectURIRequest
from authentik_client.models.sub_mode_enum import SubModeEnum
from typing import Optional, Set
from typing_extensions import Self

class PatchedOAuth2ProviderRequest(BaseModel):
    """
    OAuth2Provider Serializer
    """ # noqa: E501
    name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None
    authentication_flow: Optional[StrictStr] = Field(default=None, description="Flow used for authentication when the associated application is accessed by an un-authenticated user.")
    authorization_flow: Optional[StrictStr] = Field(default=None, description="Flow used when authorizing this provider.")
    invalidation_flow: Optional[StrictStr] = Field(default=None, description="Flow used ending the session from a provider.")
    property_mappings: Optional[List[StrictStr]] = None
    client_type: Optional[ClientTypeEnum] = Field(default=None, description="Confidential clients are capable of maintaining the confidentiality of their credentials. Public clients are incapable")
    client_id: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=255)]] = None
    client_secret: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    access_code_validity: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Access codes not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).")
    access_token_validity: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).")
    refresh_token_validity: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).")
    include_claims_in_id_token: Optional[StrictBool] = Field(default=None, description="Include User claims from scopes in the id_token, for applications that don't access the userinfo endpoint.")
    signing_key: Optional[StrictStr] = Field(default=None, description="Key used to sign the tokens.")
    encryption_key: Optional[StrictStr] = Field(default=None, description="Key used to encrypt the tokens. When set, tokens will be encrypted and returned as JWEs.")
    redirect_uris: Optional[List[RedirectURIRequest]] = None
    sub_mode: Optional[SubModeEnum] = Field(default=None, description="Configure what data should be used as unique User Identifier. For most cases, the default should be fine.")
    issuer_mode: Optional[IssuerModeEnum] = Field(default=None, description="Configure how the issuer field of the ID Token should be filled.")
    jwt_federation_sources: Optional[List[StrictStr]] = None
    jwt_federation_providers: Optional[List[StrictInt]] = None
    __properties: ClassVar[List[str]] = ["name", "authentication_flow", "authorization_flow", "invalidation_flow", "property_mappings", "client_type", "client_id", "client_secret", "access_code_validity", "access_token_validity", "refresh_token_validity", "include_claims_in_id_token", "signing_key", "encryption_key", "redirect_uris", "sub_mode", "issuer_mode", "jwt_federation_sources", "jwt_federation_providers"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PatchedOAuth2ProviderRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in redirect_uris (list)
        _items = []
        if self.redirect_uris:
            for _item in self.redirect_uris:
                if _item:
                    _items.append(_item.to_dict())
            _dict['redirect_uris'] = _items
        # set to None if authentication_flow (nullable) is None
        # and model_fields_set contains the field
        if self.authentication_flow is None and "authentication_flow" in self.model_fields_set:
            _dict['authentication_flow'] = None

        # set to None if signing_key (nullable) is None
        # and model_fields_set contains the field
        if self.signing_key is None and "signing_key" in self.model_fields_set:
            _dict['signing_key'] = None

        # set to None if encryption_key (nullable) is None
        # and model_fields_set contains the field
        if self.encryption_key is None and "encryption_key" in self.model_fields_set:
            _dict['encryption_key'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PatchedOAuth2ProviderRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "authentication_flow": obj.get("authentication_flow"),
            "authorization_flow": obj.get("authorization_flow"),
            "invalidation_flow": obj.get("invalidation_flow"),
            "property_mappings": obj.get("property_mappings"),
            "client_type": obj.get("client_type"),
            "client_id": obj.get("client_id"),
            "client_secret": obj.get("client_secret"),
            "access_code_validity": obj.get("access_code_validity"),
            "access_token_validity": obj.get("access_token_validity"),
            "refresh_token_validity": obj.get("refresh_token_validity"),
            "include_claims_in_id_token": obj.get("include_claims_in_id_token"),
            "signing_key": obj.get("signing_key"),
            "encryption_key": obj.get("encryption_key"),
            "redirect_uris": [RedirectURIRequest.from_dict(_item) for _item in obj["redirect_uris"]] if obj.get("redirect_uris") is not None else None,
            "sub_mode": obj.get("sub_mode"),
            "issuer_mode": obj.get("issuer_mode"),
            "jwt_federation_sources": obj.get("jwt_federation_sources"),
            "jwt_federation_providers": obj.get("jwt_federation_providers")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from authentik_client.models.policy_engine_mode import PolicyEngineMode
from authentik_client.models.user_matching_mode_enum import UserMatchingModeEnum
from typing import Optional, Set
from typing_extensions import Self

class LDAPSourceRequest(BaseModel):
    """
    LDAP Source Serializer
    """ # noqa: E501
    name: Annotated[str, Field(min_length=1, strict=True)] = Field(description="Source's display Name.")
    slug: Annotated[str, Field(min_length=1, strict=True, max_length=50)] = Field(description="Internal source name, used in URLs.")
    enabled: Optional[StrictBool] = None
    authentication_flow: Optional[StrictStr] = Field(default=None, description="Flow to use when authenticating existing users.")
    enrollment_flow: Optional[StrictStr] = Field(default=None, description="Flow to use when enrolling new users.")
    user_property_mappings: Optional[List[StrictStr]] = None
    group_property_mappings: Optional[List[StrictStr]] = None
    policy_engine_mode: Optional[PolicyEngineMode] = None
    user_matching_mode: Optional[UserMatchingModeEnum] = Field(default=None, description="How the source determines if an existing user should be authenticated or a new user enrolled.")
    user_path_template: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None
    server_uri: Annotated[str, Field(min_length=1, strict=True)]
    peer_certificate: Optional[StrictStr] = Field(default=None, description="Optionally verify the LDAP Server's Certificate against the CA Chain in this keypair.")
    client_certificate: Optional[StrictStr] = Field(default=None, description="Client certificate to authenticate against the LDAP Server's Certificate.")
    bind_cn: Optional[StrictStr] = None
    bind_password: Optional[StrictStr] = None
    start_tls: Optional[StrictBool] = None
    sni: Optional[StrictBool] = None
    base_dn: Annotated[str, Field(min_length=1, strict=True)]
    additional_user_dn: Optional[StrictStr] = Field(default=None, description="Prepended to Base DN for User-queries.")
    additional_group_dn: Optional[StrictStr] = Field(default=None, description="Prepended to Base DN for Group-queries.")
    user_object_filter: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Consider Objects matching this filter to be Users.")
    group_object_filter: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Consider Objects matching this filter to be Groups.")
    group_membership_field: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Field which contains members of a group.")
    object_uniqueness_field: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Field which contains a unique Identifier.")
    password_login_update_internal_password: Optional[StrictBool] = Field(default=None, description="Update internal authentik password when login succeeds with LDAP")
    sync_users: Optional[StrictBool] = None
    sync_users_password: Optional[StrictBool] = Field(default=None, description="When a user changes their password, sync it back to LDAP. This can only be enabled on a single LDAP source.")
    sync_groups: Optional[StrictBool] = None
    sync_parent_group: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["name", "slug", "enabled", "authentication_flow", "enrollment_flow", "user_property_mappings", "group_property_mappings", "policy_engine_mode", "user_matching_mode", "user_path_template", "server_uri", "peer_certificate", "client_certificate", "bind_cn", "bind_password", "start_tls", "sni", "base_dn", "additional_user_dn", "additional_group_dn", "user_object_filter", "group_object_filter", "group_membership_field", "object_uniqueness_field", "password_login_update_internal_password", "sync_users", "sync_users_password", "sync_groups", "sync_parent_group"]

    @field_validator('slug')
    def slug_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[-a-zA-Z0-9_]+$", value):
            raise ValueError(r"must validate the regular expression /^[-a-zA-Z0-9_]+$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LDAPSourceRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if authentication_flow (nullable) is None
        # and model_fields_set contains the field
        if self.authentication_flow is None and "authentication_flow" in self.model_fields_set:
            _dict['authentication_flow'] = None

        # set to None if enrollment_flow (nullable) is None
        # and model_fields_set contains the field
        if self.enrollment_flow is None and "enrollment_flow" in self.model_fields_set:
            _dict['enrollment_flow'] = None

        # set to None if peer_certificate (nullable) is None
        # and model_fields_set contains the field
        if self.peer_certificate is None and "peer_certificate" in self.model_fields_set:
            _dict['peer_certificate'] = None

        # set to None if client_certificate (nullable) is None
        # and model_fields_set contains the field
        if self.client_certificate is None and "client_certificate" in self.model_fields_set:
            _dict['client_certificate'] = None

        # set to None if sync_parent_group (nullable) is None
        # and model_fields_set contains the field
        if self.sync_parent_group is None and "sync_parent_group" in self.model_fields_set:
            _dict['sync_parent_group'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LDAPSourceRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "slug": obj.get("slug"),
            "enabled": obj.get("enabled"),
            "authentication_flow": obj.get("authentication_flow"),
            "enrollment_flow": obj.get("enrollment_flow"),
            "user_property_mappings": obj.get("user_property_mappings"),
            "group_property_mappings": obj.get("group_property_mappings"),
            "policy_engine_mode": obj.get("policy_engine_mode"),
            "user_matching_mode": obj.get("user_matching_mode"),
            "user_path_template": obj.get("user_path_template"),
            "server_uri": obj.get("server_uri"),
            "peer_certificate": obj.get("peer_certificate"),
            "client_certificate": obj.get("client_certificate"),
            "bind_cn": obj.get("bind_cn"),
            "bind_password": obj.get("bind_password"),
            "start_tls": obj.get("start_tls"),
            "sni": obj.get("sni"),
            "base_dn": obj.get("base_dn"),
            "additional_user_dn": obj.get("additional_user_dn"),
            "additional_group_dn": obj.get("additional_group_dn"),
            "user_object_filter": obj.get("user_object_filter"),
            "group_object_filter": obj.get("group_object_filter"),
            "group_membership_field": obj.get("group_membership_field"),
            "object_uniqueness_field": obj.get("object_uniqueness_field"),
            "password_login_update_internal_password": obj.get("password_login_update_internal_password"),
            "sync_users": obj.get("sync_users"),
            "sync_users_password": obj.get("sync_users_password"),
            "sync_groups": obj.get("sync_groups"),
            "sync_parent_group": obj.get("sync_parent_group")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.certificate_key_pair import CertificateKeyPair

class TestCertificateKeyPair(unittest.TestCase):
    """CertificateKeyPair unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CertificateKeyPair:
        """Test CertificateKeyPair
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CertificateKeyPair`
        """
        model = CertificateKeyPair()
        if include_optional:
            return CertificateKeyPair(
                pk = '',
                name = '',
                fingerprint_sha256 = '',
                fingerprint_sha1 = '',
                cert_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                cert_subject = '',
                private_key_available = True,
                private_key_type = '',
                certificate_download_url = '',
                private_key_download_url = '',
                managed = ''
            )
        else:
            return CertificateKeyPair(
                pk = '',
                name = '',
                fingerprint_sha256 = '',
                fingerprint_sha1 = '',
                cert_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                cert_subject = '',
                private_key_available = True,
                private_key_type = '',
                certificate_download_url = '',
                private_key_download_url = '',
                managed = '',
        )
        """

    def testCertificateKeyPair(self):
        """Test CertificateKeyPair"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class DockerServiceConnection(BaseModel):
    """
    DockerServiceConnection Serializer
    """ # noqa: E501
    pk: StrictStr
    name: StrictStr
    local: Optional[StrictBool] = Field(default=None, description="If enabled, use the local connection. Required Docker socket/Kubernetes Integration")
    component: StrictStr
    verbose_name: StrictStr = Field(description="Return object's verbose_name")
    verbose_name_plural: StrictStr = Field(description="Return object's plural verbose_name")
    meta_model_name: StrictStr = Field(description="Return internal model name")
    url: StrictStr = Field(description="Can be in the format of 'unix://<path>' when connecting to a local docker daemon, or 'https://<hostname>:2376' when connecting to a remote system.")
    tls_verification: Optional[StrictStr] = Field(default=None, description="CA which the endpoint's Certificate is verified against. Can be left empty for no validation.")
    tls_authentication: Optional[StrictStr] = Field(default=None, description="Certificate/Key used for authentication. Can be left empty for no authentication.")
    __properties: ClassVar[List[str]] = ["pk", "name", "local", "component", "verbose_name", "verbose_name_plural", "meta_model_name", "url", "tls_verification", "tls_authentication"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DockerServiceConnection from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pk",
            "component",
            "verbose_name",
            "verbose_name_plural",
            "meta_model_name",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if tls_verification (nullable) is None
        # and model_fields_set contains the field
        if self.tls_verification is None and "tls_verification" in self.model_fields_set:
            _dict['tls_verification'] = None

        # set to None if tls_authentication (nullable) is None
        # and model_fields_set contains the field
        if self.tls_authentication is None and "tls_authentication" in self.model_fields_set:
            _dict['tls_authentication'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DockerServiceConnection from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "pk": obj.get("pk"),
            "name": obj.get("name"),
            "local": obj.get("local"),
            "component": obj.get("component"),
            "verbose_name": obj.get("verbose_name"),
            "verbose_name_plural": obj.get("verbose_name_plural"),
            "meta_model_name": obj.get("meta_model_name"),
            "url": obj.get("url"),
            "tls_verification": obj.get("tls_verification"),
            "tls_authentication": obj.get("tls_authentication")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.paginated_password_policy_list import PaginatedPasswordPolicyList

class TestPaginatedPasswordPolicyList(unittest.TestCase):
    """PaginatedPasswordPolicyList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedPasswordPolicyList:
        """Test PaginatedPasswordPolicyList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedPasswordPolicyList`
        """
        model = PaginatedPasswordPolicyList()
        if include_optional:
            return PaginatedPasswordPolicyList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.password_policy.PasswordPolicy(
                        pk = '', 
                        name = '', 
                        execution_logging = True, 
                        component = '', 
                        verbose_name = '', 
                        verbose_name_plural = '', 
                        meta_model_name = '', 
                        bound_to = 56, 
                        password_field = '', 
                        amount_digits = 0, 
                        amount_uppercase = 0, 
                        amount_lowercase = 0, 
                        amount_symbols = 0, 
                        length_min = 0, 
                        symbol_charset = '', 
                        error_message = '', 
                        check_static_rules = True, 
                        check_have_i_been_pwned = True, 
                        check_zxcvbn = True, 
                        hibp_allowed_count = 0, 
                        zxcvbn_score_threshold = 0, )
                    ]
            )
        else:
            return PaginatedPasswordPolicyList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.password_policy.PasswordPolicy(
                        pk = '', 
                        name = '', 
                        execution_logging = True, 
                        component = '', 
                        verbose_name = '', 
                        verbose_name_plural = '', 
                        meta_model_name = '', 
                        bound_to = 56, 
                        password_field = '', 
                        amount_digits = 0, 
                        amount_uppercase = 0, 
                        amount_lowercase = 0, 
                        amount_symbols = 0, 
                        length_min = 0, 
                        symbol_charset = '', 
                        error_message = '', 
                        check_static_rules = True, 
                        check_have_i_been_pwned = True, 
                        check_zxcvbn = True, 
                        hibp_allowed_count = 0, 
                        zxcvbn_score_threshold = 0, )
                    ],
        )
        """

    def testPaginatedPasswordPolicyList(self):
        """Test PaginatedPasswordPolicyList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class Provider(BaseModel):
    """
    Provider Serializer
    """ # noqa: E501
    pk: StrictInt
    name: StrictStr
    authentication_flow: Optional[StrictStr] = Field(default=None, description="Flow used for authentication when the associated application is accessed by an un-authenticated user.")
    authorization_flow: StrictStr = Field(description="Flow used when authorizing this provider.")
    invalidation_flow: StrictStr = Field(description="Flow used ending the session from a provider.")
    property_mappings: Optional[List[StrictStr]] = None
    component: StrictStr = Field(description="Get object component so that we know how to edit the object")
    assigned_application_slug: StrictStr = Field(description="Internal application name, used in URLs.")
    assigned_application_name: StrictStr = Field(description="Application's display Name.")
    assigned_backchannel_application_slug: StrictStr = Field(description="Internal application name, used in URLs.")
    assigned_backchannel_application_name: StrictStr = Field(description="Application's display Name.")
    verbose_name: StrictStr = Field(description="Return object's verbose_name")
    verbose_name_plural: StrictStr = Field(description="Return object's plural verbose_name")
    meta_model_name: StrictStr = Field(description="Return internal model name")
    __properties: ClassVar[List[str]] = ["pk", "name", "authentication_flow", "authorization_flow", "invalidation_flow", "property_mappings", "component", "assigned_application_slug", "assigned_application_name", "assigned_backchannel_application_slug", "assigned_backchannel_application_name", "verbose_name", "verbose_name_plural", "meta_model_name"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Provider from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pk",
            "component",
            "assigned_application_slug",
            "assigned_application_name",
            "assigned_backchannel_application_slug",
            "assigned_backchannel_application_name",
            "verbose_name",
            "verbose_name_plural",
            "meta_model_name",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if authentication_flow (nullable) is None
        # and model_fields_set contains the field
        if self.authentication_flow is None and "authentication_flow" in self.model_fields_set:
            _dict['authentication_flow'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Provider from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "pk": obj.get("pk"),
            "name": obj.get("name"),
            "authentication_flow": obj.get("authentication_flow"),
            "authorization_flow": obj.get("authorization_flow"),
            "invalidation_flow": obj.get("invalidation_flow"),
            "property_mappings": obj.get("property_mappings"),
            "component": obj.get("component"),
            "assigned_application_slug": obj.get("assigned_application_slug"),
            "assigned_application_name": obj.get("assigned_application_name"),
            "assigned_backchannel_application_slug": obj.get("assigned_backchannel_application_slug"),
            "assigned_backchannel_application_name": obj.get("assigned_backchannel_application_name"),
            "verbose_name": obj.get("verbose_name"),
            "verbose_name_plural": obj.get("verbose_name_plural"),
            "meta_model_name": obj.get("meta_model_name")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.identification_challenge import IdentificationChallenge

class TestIdentificationChallenge(unittest.TestCase):
    """IdentificationChallenge unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IdentificationChallenge:
        """Test IdentificationChallenge
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IdentificationChallenge`
        """
        model = IdentificationChallenge()
        if include_optional:
            return IdentificationChallenge(
                flow_info = authentik_client.models.contextual_flow_info.ContextualFlowInfo(
                    title = '', 
                    background = '', 
                    cancel_url = '', 
                    layout = 'stacked', ),
                component = 'ak-stage-identification',
                response_errors = {
                    'key' : [
                        authentik_client.models.error_detail.ErrorDetail(
                            string = '', 
                            code = '', )
                        ]
                    },
                user_fields = [
                    ''
                    ],
                password_fields = True,
                allow_show_password = True,
                application_pre = '',
                flow_designation = 'authentication',
                captcha_stage = authentik_client.models.captcha_challenge.CaptchaChallenge(
                    flow_info = authentik_client.models.contextual_flow_info.ContextualFlowInfo(
                        title = '', 
                        background = '', 
                        cancel_url = '', 
                        layout = 'stacked', ), 
                    component = 'ak-stage-captcha', 
                    response_errors = {
                        'key' : [
                            authentik_client.models.error_detail.ErrorDetail(
                                string = '', 
                                code = '', )
                            ]
                        }, 
                    pending_user = '', 
                    pending_user_avatar = '', 
                    site_key = '', 
                    js_url = '', 
                    interactive = True, ),
                enroll_url = '',
                recovery_url = '',
                passwordless_url = '',
                primary_action = '',
                sources = [
                    authentik_client.models.login_source.LoginSource(
                        name = '', 
                        icon_url = '', 
                        challenge = null, )
                    ],
                show_source_labels = True
            )
        else:
            return IdentificationChallenge(
                user_fields = [
                    ''
                    ],
                password_fields = True,
                flow_designation = 'authentication',
                primary_action = '',
                show_source_labels = True,
        )
        """

    def testIdentificationChallenge(self):
        """Test IdentificationChallenge"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class PromptTypeEnum(str, Enum):
    """
    PromptTypeEnum
    """

    """
    allowed enum values
    """
    TEXT = 'text'
    TEXT_AREA = 'text_area'
    TEXT_READ_ONLY = 'text_read_only'
    TEXT_AREA_READ_ONLY = 'text_area_read_only'
    USERNAME = 'username'
    EMAIL = 'email'
    PASSWORD = 'password'
    NUMBER = 'number'
    CHECKBOX = 'checkbox'
    RADIO_MINUS_BUTTON_MINUS_GROUP = 'radio-button-group'
    DROPDOWN = 'dropdown'
    DATE = 'date'
    DATE_MINUS_TIME = 'date-time'
    FILE = 'file'
    SEPARATOR = 'separator'
    HIDDEN = 'hidden'
    STATIC = 'static'
    AK_MINUS_LOCALE = 'ak-locale'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PromptTypeEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.sync_status import SyncStatus

class TestSyncStatus(unittest.TestCase):
    """SyncStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyncStatus:
        """Test SyncStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyncStatus`
        """
        model = SyncStatus()
        if include_optional:
            return SyncStatus(
                is_running = True,
                tasks = [
                    authentik_client.models.system_task.SystemTask(
                        uuid = '', 
                        name = '', 
                        full_name = '', 
                        uid = '', 
                        description = '', 
                        start_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        finish_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        duration = 1.337, 
                        status = 'unknown', 
                        messages = [
                            authentik_client.models.log_event.LogEvent(
                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                log_level = 'critical', 
                                logger = '', 
                                event = '', 
                                attributes = {
                                    'key' : null
                                    }, )
                            ], 
                        expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expiring = True, )
                    ]
            )
        else:
            return SyncStatus(
                is_running = True,
                tasks = [
                    authentik_client.models.system_task.SystemTask(
                        uuid = '', 
                        name = '', 
                        full_name = '', 
                        uid = '', 
                        description = '', 
                        start_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        finish_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        duration = 1.337, 
                        status = 'unknown', 
                        messages = [
                            authentik_client.models.log_event.LogEvent(
                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                log_level = 'critical', 
                                logger = '', 
                                event = '', 
                                attributes = {
                                    'key' : null
                                    }, )
                            ], 
                        expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expiring = True, )
                    ],
        )
        """

    def testSyncStatus(self):
        """Test SyncStatus"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FlowDesignationEnum(str, Enum):
    """
    FlowDesignationEnum
    """

    """
    allowed enum values
    """
    AUTHENTICATION = 'authentication'
    AUTHORIZATION = 'authorization'
    INVALIDATION = 'invalidation'
    ENROLLMENT = 'enrollment'
    UNENROLLMENT = 'unenrollment'
    RECOVERY = 'recovery'
    STAGE_CONFIGURATION = 'stage_configuration'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FlowDesignationEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.endpoint import Endpoint

class TestEndpoint(unittest.TestCase):
    """Endpoint unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Endpoint:
        """Test Endpoint
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Endpoint`
        """
        model = Endpoint()
        if include_optional:
            return Endpoint(
                pk = '',
                name = '',
                provider = 56,
                provider_obj = authentik_client.models.rac_provider.RACProvider(
                    pk = 56, 
                    name = '', 
                    authentication_flow = '', 
                    authorization_flow = '', 
                    property_mappings = [
                        ''
                        ], 
                    component = '', 
                    assigned_application_slug = '', 
                    assigned_application_name = '', 
                    assigned_backchannel_application_slug = '', 
                    assigned_backchannel_application_name = '', 
                    verbose_name = '', 
                    verbose_name_plural = '', 
                    meta_model_name = '', 
                    settings = null, 
                    outpost_set = [
                        ''
                        ], 
                    connection_expiry = '', 
                    delete_token_on_disconnect = True, ),
                protocol = 'rdp',
                host = '',
                settings = None,
                property_mappings = [
                    ''
                    ],
                auth_mode = 'static',
                launch_url = '',
                maximum_connections = -2147483648
            )
        else:
            return Endpoint(
                pk = '',
                name = '',
                provider = 56,
                provider_obj = authentik_client.models.rac_provider.RACProvider(
                    pk = 56, 
                    name = '', 
                    authentication_flow = '', 
                    authorization_flow = '', 
                    property_mappings = [
                        ''
                        ], 
                    component = '', 
                    assigned_application_slug = '', 
                    assigned_application_name = '', 
                    assigned_backchannel_application_slug = '', 
                    assigned_backchannel_application_name = '', 
                    verbose_name = '', 
                    verbose_name_plural = '', 
                    meta_model_name = '', 
                    settings = null, 
                    outpost_set = [
                        ''
                        ], 
                    connection_expiry = '', 
                    delete_token_on_disconnect = True, ),
                protocol = 'rdp',
                host = '',
                auth_mode = 'static',
                launch_url = '',
        )
        """

    def testEndpoint(self):
        """Test Endpoint"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.invitation import Invitation

class TestInvitation(unittest.TestCase):
    """Invitation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Invitation:
        """Test Invitation
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Invitation`
        """
        model = Invitation()
        if include_optional:
            return Invitation(
                pk = '',
                name = 'z',
                expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                fixed_data = {
                    'key' : null
                    },
                created_by = authentik_client.models.group_member.GroupMember(
                    pk = 56, 
                    username = 'A', 
                    name = '', 
                    is_active = True, 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    email = '', 
                    attributes = {
                        'key' : null
                        }, 
                    uid = '', ),
                single_use = True,
                flow = '',
                flow_obj = authentik_client.models.flow.Flow(
                    pk = '', 
                    policybindingmodel_ptr_id = '', 
                    name = '', 
                    slug = 'z', 
                    title = '', 
                    designation = null, 
                    background = '', 
                    stages = [
                        ''
                        ], 
                    policies = [
                        ''
                        ], 
                    cache_count = 56, 
                    policy_engine_mode = 'all', 
                    compatibility_mode = True, 
                    export_url = '', 
                    layout = 'stacked', 
                    denied_action = null, 
                    authentication = null, )
            )
        else:
            return Invitation(
                pk = '',
                name = 'z',
                created_by = authentik_client.models.group_member.GroupMember(
                    pk = 56, 
                    username = 'A', 
                    name = '', 
                    is_active = True, 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    email = '', 
                    attributes = {
                        'key' : null
                        }, 
                    uid = '', ),
                flow_obj = authentik_client.models.flow.Flow(
                    pk = '', 
                    policybindingmodel_ptr_id = '', 
                    name = '', 
                    slug = 'z', 
                    title = '', 
                    designation = null, 
                    background = '', 
                    stages = [
                        ''
                        ], 
                    policies = [
                        ''
                        ], 
                    cache_count = 56, 
                    policy_engine_mode = 'all', 
                    compatibility_mode = True, 
                    export_url = '', 
                    layout = 'stacked', 
                    denied_action = null, 
                    authentication = null, ),
        )
        """

    def testInvitation(self):
        """Test Invitation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.notification_transport_request import NotificationTransportRequest

class TestNotificationTransportRequest(unittest.TestCase):
    """NotificationTransportRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NotificationTransportRequest:
        """Test NotificationTransportRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NotificationTransportRequest`
        """
        model = NotificationTransportRequest()
        if include_optional:
            return NotificationTransportRequest(
                name = '0',
                mode = 'local',
                webhook_url = '',
                webhook_mapping = '',
                send_once = True
            )
        else:
            return NotificationTransportRequest(
                name = '0',
        )
        """

    def testNotificationTransportRequest(self):
        """Test NotificationTransportRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.rac_api import RacApi


class TestRacApi(unittest.TestCase):
    """RacApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RacApi()

    def tearDown(self) -> None:
        pass

    def test_rac_connection_tokens_destroy(self) -> None:
        """Test case for rac_connection_tokens_destroy

        """
        pass

    def test_rac_connection_tokens_list(self) -> None:
        """Test case for rac_connection_tokens_list

        """
        pass

    def test_rac_connection_tokens_partial_update(self) -> None:
        """Test case for rac_connection_tokens_partial_update

        """
        pass

    def test_rac_connection_tokens_retrieve(self) -> None:
        """Test case for rac_connection_tokens_retrieve

        """
        pass

    def test_rac_connection_tokens_update(self) -> None:
        """Test case for rac_connection_tokens_update

        """
        pass

    def test_rac_connection_tokens_used_by_list(self) -> None:
        """Test case for rac_connection_tokens_used_by_list

        """
        pass

    def test_rac_endpoints_create(self) -> None:
        """Test case for rac_endpoints_create

        """
        pass

    def test_rac_endpoints_destroy(self) -> None:
        """Test case for rac_endpoints_destroy

        """
        pass

    def test_rac_endpoints_list(self) -> None:
        """Test case for rac_endpoints_list

        """
        pass

    def test_rac_endpoints_partial_update(self) -> None:
        """Test case for rac_endpoints_partial_update

        """
        pass

    def test_rac_endpoints_retrieve(self) -> None:
        """Test case for rac_endpoints_retrieve

        """
        pass

    def test_rac_endpoints_update(self) -> None:
        """Test case for rac_endpoints_update

        """
        pass

    def test_rac_endpoints_used_by_list(self) -> None:
        """Test case for rac_endpoints_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.scim_provider import SCIMProvider

class TestSCIMProvider(unittest.TestCase):
    """SCIMProvider unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SCIMProvider:
        """Test SCIMProvider
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SCIMProvider`
        """
        model = SCIMProvider()
        if include_optional:
            return SCIMProvider(
                pk = 56,
                name = '',
                property_mappings = [
                    ''
                    ],
                property_mappings_group = [
                    ''
                    ],
                component = '',
                assigned_backchannel_application_slug = '',
                assigned_backchannel_application_name = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = '',
                url = '',
                verify_certificates = True,
                token = '',
                exclude_users_service_account = True,
                filter_group = ''
            )
        else:
            return SCIMProvider(
                pk = 56,
                name = '',
                component = '',
                assigned_backchannel_application_slug = '',
                assigned_backchannel_application_name = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = '',
                url = '',
                token = '',
        )
        """

    def testSCIMProvider(self):
        """Test SCIMProvider"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.oauth2_api import Oauth2Api


class TestOauth2Api(unittest.TestCase):
    """Oauth2Api unit test stubs"""

    def setUp(self) -> None:
        self.api = Oauth2Api()

    def tearDown(self) -> None:
        pass

    def test_oauth2_access_tokens_destroy(self) -> None:
        """Test case for oauth2_access_tokens_destroy

        """
        pass

    def test_oauth2_access_tokens_list(self) -> None:
        """Test case for oauth2_access_tokens_list

        """
        pass

    def test_oauth2_access_tokens_retrieve(self) -> None:
        """Test case for oauth2_access_tokens_retrieve

        """
        pass

    def test_oauth2_access_tokens_used_by_list(self) -> None:
        """Test case for oauth2_access_tokens_used_by_list

        """
        pass

    def test_oauth2_authorization_codes_destroy(self) -> None:
        """Test case for oauth2_authorization_codes_destroy

        """
        pass

    def test_oauth2_authorization_codes_list(self) -> None:
        """Test case for oauth2_authorization_codes_list

        """
        pass

    def test_oauth2_authorization_codes_retrieve(self) -> None:
        """Test case for oauth2_authorization_codes_retrieve

        """
        pass

    def test_oauth2_authorization_codes_used_by_list(self) -> None:
        """Test case for oauth2_authorization_codes_used_by_list

        """
        pass

    def test_oauth2_refresh_tokens_destroy(self) -> None:
        """Test case for oauth2_refresh_tokens_destroy

        """
        pass

    def test_oauth2_refresh_tokens_list(self) -> None:
        """Test case for oauth2_refresh_tokens_list

        """
        pass

    def test_oauth2_refresh_tokens_retrieve(self) -> None:
        """Test case for oauth2_refresh_tokens_retrieve

        """
        pass

    def test_oauth2_refresh_tokens_used_by_list(self) -> None:
        """Test case for oauth2_refresh_tokens_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.o_auth_device_code_finish_challenge_response_request import OAuthDeviceCodeFinishChallengeResponseRequest

class TestOAuthDeviceCodeFinishChallengeResponseRequest(unittest.TestCase):
    """OAuthDeviceCodeFinishChallengeResponseRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OAuthDeviceCodeFinishChallengeResponseRequest:
        """Test OAuthDeviceCodeFinishChallengeResponseRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OAuthDeviceCodeFinishChallengeResponseRequest`
        """
        model = OAuthDeviceCodeFinishChallengeResponseRequest()
        if include_optional:
            return OAuthDeviceCodeFinishChallengeResponseRequest(
                component = 'ak-provider-oauth2-device-code-finish'
            )
        else:
            return OAuthDeviceCodeFinishChallengeResponseRequest(
        )
        """

    def testOAuthDeviceCodeFinishChallengeResponseRequest(self):
        """Test OAuthDeviceCodeFinishChallengeResponseRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.radius_check_access import RadiusCheckAccess

class TestRadiusCheckAccess(unittest.TestCase):
    """RadiusCheckAccess unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RadiusCheckAccess:
        """Test RadiusCheckAccess
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RadiusCheckAccess`
        """
        model = RadiusCheckAccess()
        if include_optional:
            return RadiusCheckAccess(
                attributes = '',
                access = authentik_client.models.policy_test_result.PolicyTestResult(
                    passing = True, 
                    messages = [
                        ''
                        ], 
                    log_messages = [
                        authentik_client.models.log_event.LogEvent(
                            timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            log_level = 'critical', 
                            logger = '', 
                            event = '', 
                            attributes = {
                                'key' : null
                                }, )
                        ], )
            )
        else:
            return RadiusCheckAccess(
                access = authentik_client.models.policy_test_result.PolicyTestResult(
                    passing = True, 
                    messages = [
                        ''
                        ], 
                    log_messages = [
                        authentik_client.models.log_event.LogEvent(
                            timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            log_level = 'critical', 
                            logger = '', 
                            event = '', 
                            attributes = {
                                'key' : null
                                }, )
                        ], ),
        )
        """

    def testRadiusCheckAccess(self):
        """Test RadiusCheckAccess"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.policy_binding_request import PolicyBindingRequest

class TestPolicyBindingRequest(unittest.TestCase):
    """PolicyBindingRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PolicyBindingRequest:
        """Test PolicyBindingRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PolicyBindingRequest`
        """
        model = PolicyBindingRequest()
        if include_optional:
            return PolicyBindingRequest(
                policy = '',
                group = '',
                user = 56,
                target = '',
                negate = True,
                enabled = True,
                order = -2147483648,
                timeout = 0,
                failure_result = True
            )
        else:
            return PolicyBindingRequest(
                target = '',
                order = -2147483648,
        )
        """

    def testPolicyBindingRequest(self):
        """Test PolicyBindingRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.authenticated_session import AuthenticatedSession

class TestAuthenticatedSession(unittest.TestCase):
    """AuthenticatedSession unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuthenticatedSession:
        """Test AuthenticatedSession
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthenticatedSession`
        """
        model = AuthenticatedSession()
        if include_optional:
            return AuthenticatedSession(
                uuid = '',
                current = True,
                user_agent = authentik_client.models.authenticated_session_user_agent.AuthenticatedSession_user_agent(
                    device = authentik_client.models.authenticated_session_user_agent_device.AuthenticatedSession_user_agent_device(
                        brand = '', 
                        family = '', 
                        model = '', ), 
                    os = authentik_client.models.authenticated_session_user_agent_os.AuthenticatedSession_user_agent_os(
                        family = '', 
                        major = '', 
                        minor = '', 
                        patch = '', 
                        patch_minor = '', ), 
                    user_agent = authentik_client.models.authenticated_session_user_agent_user_agent.AuthenticatedSession_user_agent_user_agent(
                        family = '', 
                        major = '', 
                        minor = '', 
                        patch = '', ), 
                    string = '', ),
                geo_ip = authentik_client.models.authenticated_session_geo_ip.AuthenticatedSession_geo_ip(
                    continent = '', 
                    country = '', 
                    lat = 1.337, 
                    long = 1.337, 
                    city = '', ),
                asn = authentik_client.models.authenticated_session_asn.AuthenticatedSession_asn(
                    asn = 56, 
                    as_org = '', 
                    network = '', ),
                user = 56,
                last_ip = '',
                last_user_agent = '',
                last_used = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return AuthenticatedSession(
                current = True,
                user_agent = authentik_client.models.authenticated_session_user_agent.AuthenticatedSession_user_agent(
                    device = authentik_client.models.authenticated_session_user_agent_device.AuthenticatedSession_user_agent_device(
                        brand = '', 
                        family = '', 
                        model = '', ), 
                    os = authentik_client.models.authenticated_session_user_agent_os.AuthenticatedSession_user_agent_os(
                        family = '', 
                        major = '', 
                        minor = '', 
                        patch = '', 
                        patch_minor = '', ), 
                    user_agent = authentik_client.models.authenticated_session_user_agent_user_agent.AuthenticatedSession_user_agent_user_agent(
                        family = '', 
                        major = '', 
                        minor = '', 
                        patch = '', ), 
                    string = '', ),
                geo_ip = authentik_client.models.authenticated_session_geo_ip.AuthenticatedSession_geo_ip(
                    continent = '', 
                    country = '', 
                    lat = 1.337, 
                    long = 1.337, 
                    city = '', ),
                asn = authentik_client.models.authenticated_session_asn.AuthenticatedSession_asn(
                    asn = 56, 
                    as_org = '', 
                    network = '', ),
                user = 56,
                last_ip = '',
                last_used = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testAuthenticatedSession(self):
        """Test AuthenticatedSession"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.authenticator_static_stage_request import AuthenticatorStaticStageRequest

class TestAuthenticatorStaticStageRequest(unittest.TestCase):
    """AuthenticatorStaticStageRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuthenticatorStaticStageRequest:
        """Test AuthenticatorStaticStageRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthenticatorStaticStageRequest`
        """
        model = AuthenticatorStaticStageRequest()
        if include_optional:
            return AuthenticatorStaticStageRequest(
                name = '0',
                flow_set = [
                    authentik_client.models.flow_set_request.FlowSetRequest(
                        name = '0', 
                        slug = 'z0', 
                        title = '0', 
                        designation = null, 
                        policy_engine_mode = 'all', 
                        compatibility_mode = True, 
                        layout = 'stacked', 
                        denied_action = null, )
                    ],
                configure_flow = '',
                friendly_name = '0',
                token_count = 0,
                token_length = 0
            )
        else:
            return AuthenticatorStaticStageRequest(
                name = '0',
        )
        """

    def testAuthenticatorStaticStageRequest(self):
        """Test AuthenticatorStaticStageRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from authentik_client.models.flow_set_request import FlowSetRequest
from typing import Optional, Set
from typing_extensions import Self

class PatchedAuthenticatorEmailStageRequest(BaseModel):
    """
    AuthenticatorEmailStage Serializer
    """ # noqa: E501
    name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None
    flow_set: Optional[List[FlowSetRequest]] = None
    configure_flow: Optional[StrictStr] = Field(default=None, description="Flow used by an authenticated user to configure this Stage. If empty, user will not be able to configure this stage.")
    friendly_name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None
    use_global_settings: Optional[StrictBool] = Field(default=None, description="When enabled, global Email connection settings will be used and connection settings below will be ignored.")
    host: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None
    port: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=-2147483648)]] = None
    username: Optional[StrictStr] = None
    password: Optional[StrictStr] = None
    use_tls: Optional[StrictBool] = None
    use_ssl: Optional[StrictBool] = None
    timeout: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=-2147483648)]] = None
    from_address: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=254)]] = None
    subject: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None
    token_expiry: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Time the token sent is valid (Format: hours=3,minutes=17,seconds=300).")
    template: Optional[Annotated[str, Field(min_length=1, strict=True)]] = None
    __properties: ClassVar[List[str]] = ["name", "flow_set", "configure_flow", "friendly_name", "use_global_settings", "host", "port", "username", "password", "use_tls", "use_ssl", "timeout", "from_address", "subject", "token_expiry", "template"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PatchedAuthenticatorEmailStageRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in flow_set (list)
        _items = []
        if self.flow_set:
            for _item in self.flow_set:
                if _item:
                    _items.append(_item.to_dict())
            _dict['flow_set'] = _items
        # set to None if configure_flow (nullable) is None
        # and model_fields_set contains the field
        if self.configure_flow is None and "configure_flow" in self.model_fields_set:
            _dict['configure_flow'] = None

        # set to None if friendly_name (nullable) is None
        # and model_fields_set contains the field
        if self.friendly_name is None and "friendly_name" in self.model_fields_set:
            _dict['friendly_name'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PatchedAuthenticatorEmailStageRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "flow_set": [FlowSetRequest.from_dict(_item) for _item in obj["flow_set"]] if obj.get("flow_set") is not None else None,
            "configure_flow": obj.get("configure_flow"),
            "friendly_name": obj.get("friendly_name"),
            "use_global_settings": obj.get("use_global_settings"),
            "host": obj.get("host"),
            "port": obj.get("port"),
            "username": obj.get("username"),
            "password": obj.get("password"),
            "use_tls": obj.get("use_tls"),
            "use_ssl": obj.get("use_ssl"),
            "timeout": obj.get("timeout"),
            "from_address": obj.get("from_address"),
            "subject": obj.get("subject"),
            "token_expiry": obj.get("token_expiry"),
            "template": obj.get("template")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from authentik_client.models.authenticated_session_asn import AuthenticatedSessionAsn
from authentik_client.models.authenticated_session_geo_ip import AuthenticatedSessionGeoIp
from authentik_client.models.authenticated_session_user_agent import AuthenticatedSessionUserAgent
from typing import Optional, Set
from typing_extensions import Self

class AuthenticatedSession(BaseModel):
    """
    AuthenticatedSession Serializer
    """ # noqa: E501
    uuid: Optional[StrictStr] = None
    current: StrictBool = Field(description="Check if session is currently active session")
    user_agent: AuthenticatedSessionUserAgent
    geo_ip: Optional[AuthenticatedSessionGeoIp]
    asn: Optional[AuthenticatedSessionAsn]
    user: StrictInt
    last_ip: StrictStr
    last_user_agent: Optional[StrictStr] = None
    last_used: datetime
    expires: Optional[datetime] = None
    __properties: ClassVar[List[str]] = ["uuid", "current", "user_agent", "geo_ip", "asn", "user", "last_ip", "last_user_agent", "last_used", "expires"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AuthenticatedSession from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "current",
            "last_used",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of user_agent
        if self.user_agent:
            _dict['user_agent'] = self.user_agent.to_dict()
        # override the default output from pydantic by calling `to_dict()` of geo_ip
        if self.geo_ip:
            _dict['geo_ip'] = self.geo_ip.to_dict()
        # override the default output from pydantic by calling `to_dict()` of asn
        if self.asn:
            _dict['asn'] = self.asn.to_dict()
        # set to None if geo_ip (nullable) is None
        # and model_fields_set contains the field
        if self.geo_ip is None and "geo_ip" in self.model_fields_set:
            _dict['geo_ip'] = None

        # set to None if asn (nullable) is None
        # and model_fields_set contains the field
        if self.asn is None and "asn" in self.model_fields_set:
            _dict['asn'] = None

        # set to None if expires (nullable) is None
        # and model_fields_set contains the field
        if self.expires is None and "expires" in self.model_fields_set:
            _dict['expires'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AuthenticatedSession from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "uuid": obj.get("uuid"),
            "current": obj.get("current"),
            "user_agent": AuthenticatedSessionUserAgent.from_dict(obj["user_agent"]) if obj.get("user_agent") is not None else None,
            "geo_ip": AuthenticatedSessionGeoIp.from_dict(obj["geo_ip"]) if obj.get("geo_ip") is not None else None,
            "asn": AuthenticatedSessionAsn.from_dict(obj["asn"]) if obj.get("asn") is not None else None,
            "user": obj.get("user"),
            "last_ip": obj.get("last_ip"),
            "last_user_agent": obj.get("last_user_agent"),
            "last_used": obj.get("last_used"),
            "expires": obj.get("expires")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.paginated_user_consent_list import PaginatedUserConsentList

class TestPaginatedUserConsentList(unittest.TestCase):
    """PaginatedUserConsentList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedUserConsentList:
        """Test PaginatedUserConsentList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedUserConsentList`
        """
        model = PaginatedUserConsentList()
        if include_optional:
            return PaginatedUserConsentList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.user_consent.UserConsent(
                        pk = 56, 
                        expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expiring = True, 
                        user = authentik_client.models.user.User(
                            pk = 56, 
                            username = '', 
                            name = '', 
                            is_active = True, 
                            last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            is_superuser = True, 
                            groups = [
                                ''
                                ], 
                            groups_obj = [
                                authentik_client.models.user_group.UserGroup(
                                    pk = '', 
                                    num_pk = 56, 
                                    name = '', 
                                    is_superuser = True, 
                                    parent = '', 
                                    parent_name = '', 
                                    attributes = {
                                        'key' : null
                                        }, )
                                ], 
                            email = '', 
                            avatar = '', 
                            attributes = {
                                'key' : null
                                }, 
                            uid = '', 
                            path = '', 
                            type = 'internal', 
                            uuid = '', 
                            password_change_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        application = authentik_client.models.application.Application(
                            pk = '', 
                            name = '', 
                            slug = 'z', 
                            provider = 56, 
                            provider_obj = null, 
                            backchannel_providers = [
                                56
                                ], 
                            backchannel_providers_obj = [
                                authentik_client.models.provider.Provider(
                                    pk = 56, 
                                    name = '', 
                                    authentication_flow = '', 
                                    authorization_flow = '', 
                                    invalidation_flow = '', 
                                    property_mappings = [
                                        ''
                                        ], 
                                    component = '', 
                                    assigned_application_slug = '', 
                                    assigned_application_name = '', 
                                    assigned_backchannel_application_slug = '', 
                                    assigned_backchannel_application_name = '', 
                                    verbose_name = '', 
                                    verbose_name_plural = '', 
                                    meta_model_name = '', )
                                ], 
                            launch_url = '', 
                            open_in_new_tab = True, 
                            meta_launch_url = '', 
                            meta_icon = '', 
                            meta_description = '', 
                            meta_publisher = '', 
                            policy_engine_mode = 'all', 
                            group = '', ), 
                        permissions = '', )
                    ]
            )
        else:
            return PaginatedUserConsentList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.user_consent.UserConsent(
                        pk = 56, 
                        expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expiring = True, 
                        user = authentik_client.models.user.User(
                            pk = 56, 
                            username = '', 
                            name = '', 
                            is_active = True, 
                            last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            is_superuser = True, 
                            groups = [
                                ''
                                ], 
                            groups_obj = [
                                authentik_client.models.user_group.UserGroup(
                                    pk = '', 
                                    num_pk = 56, 
                                    name = '', 
                                    is_superuser = True, 
                                    parent = '', 
                                    parent_name = '', 
                                    attributes = {
                                        'key' : null
                                        }, )
                                ], 
                            email = '', 
                            avatar = '', 
                            attributes = {
                                'key' : null
                                }, 
                            uid = '', 
                            path = '', 
                            type = 'internal', 
                            uuid = '', 
                            password_change_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        application = authentik_client.models.application.Application(
                            pk = '', 
                            name = '', 
                            slug = 'z', 
                            provider = 56, 
                            provider_obj = null, 
                            backchannel_providers = [
                                56
                                ], 
                            backchannel_providers_obj = [
                                authentik_client.models.provider.Provider(
                                    pk = 56, 
                                    name = '', 
                                    authentication_flow = '', 
                                    authorization_flow = '', 
                                    invalidation_flow = '', 
                                    property_mappings = [
                                        ''
                                        ], 
                                    component = '', 
                                    assigned_application_slug = '', 
                                    assigned_application_name = '', 
                                    assigned_backchannel_application_slug = '', 
                                    assigned_backchannel_application_name = '', 
                                    verbose_name = '', 
                                    verbose_name_plural = '', 
                                    meta_model_name = '', )
                                ], 
                            launch_url = '', 
                            open_in_new_tab = True, 
                            meta_launch_url = '', 
                            meta_icon = '', 
                            meta_description = '', 
                            meta_publisher = '', 
                            policy_engine_mode = 'all', 
                            group = '', ), 
                        permissions = '', )
                    ],
        )
        """

    def testPaginatedUserConsentList(self):
        """Test PaginatedUserConsentList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.connection_token import ConnectionToken

class TestConnectionToken(unittest.TestCase):
    """ConnectionToken unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ConnectionToken:
        """Test ConnectionToken
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ConnectionToken`
        """
        model = ConnectionToken()
        if include_optional:
            return ConnectionToken(
                pk = '',
                provider = 56,
                provider_obj = authentik_client.models.rac_provider.RACProvider(
                    pk = 56, 
                    name = '', 
                    authentication_flow = '', 
                    authorization_flow = '', 
                    property_mappings = [
                        ''
                        ], 
                    component = '', 
                    assigned_application_slug = '', 
                    assigned_application_name = '', 
                    assigned_backchannel_application_slug = '', 
                    assigned_backchannel_application_name = '', 
                    verbose_name = '', 
                    verbose_name_plural = '', 
                    meta_model_name = '', 
                    settings = null, 
                    outpost_set = [
                        ''
                        ], 
                    connection_expiry = '', 
                    delete_token_on_disconnect = True, ),
                endpoint = '',
                endpoint_obj = authentik_client.models.endpoint.Endpoint(
                    pk = '', 
                    name = '', 
                    provider = 56, 
                    provider_obj = null, 
                    protocol = 'rdp', 
                    host = '', 
                    settings = null, 
                    property_mappings = [
                        ''
                        ], 
                    auth_mode = 'static', 
                    launch_url = '', 
                    maximum_connections = -2147483648, ),
                user = authentik_client.models.group_member.GroupMember(
                    pk = 56, 
                    username = 'A', 
                    name = '', 
                    is_active = True, 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    email = '', 
                    attributes = {
                        'key' : null
                        }, 
                    uid = '', )
            )
        else:
            return ConnectionToken(
                provider = 56,
                provider_obj = authentik_client.models.rac_provider.RACProvider(
                    pk = 56, 
                    name = '', 
                    authentication_flow = '', 
                    authorization_flow = '', 
                    property_mappings = [
                        ''
                        ], 
                    component = '', 
                    assigned_application_slug = '', 
                    assigned_application_name = '', 
                    assigned_backchannel_application_slug = '', 
                    assigned_backchannel_application_name = '', 
                    verbose_name = '', 
                    verbose_name_plural = '', 
                    meta_model_name = '', 
                    settings = null, 
                    outpost_set = [
                        ''
                        ], 
                    connection_expiry = '', 
                    delete_token_on_disconnect = True, ),
                endpoint = '',
                endpoint_obj = authentik_client.models.endpoint.Endpoint(
                    pk = '', 
                    name = '', 
                    provider = 56, 
                    provider_obj = null, 
                    protocol = 'rdp', 
                    host = '', 
                    settings = null, 
                    property_mappings = [
                        ''
                        ], 
                    auth_mode = 'static', 
                    launch_url = '', 
                    maximum_connections = -2147483648, ),
                user = authentik_client.models.group_member.GroupMember(
                    pk = 56, 
                    username = 'A', 
                    name = '', 
                    is_active = True, 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    email = '', 
                    attributes = {
                        'key' : null
                        }, 
                    uid = '', ),
        )
        """

    def testConnectionToken(self):
        """Test ConnectionToken"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from authentik_client.models.digest_algorithm_enum import DigestAlgorithmEnum
from authentik_client.models.signature_algorithm_enum import SignatureAlgorithmEnum
from authentik_client.models.sp_binding_enum import SpBindingEnum
from typing import Optional, Set
from typing_extensions import Self

class SAMLProviderRequest(BaseModel):
    """
    SAMLProvider Serializer
    """ # noqa: E501
    name: Annotated[str, Field(min_length=1, strict=True)]
    authentication_flow: Optional[StrictStr] = Field(default=None, description="Flow used for authentication when the associated application is accessed by an un-authenticated user.")
    authorization_flow: StrictStr = Field(description="Flow used when authorizing this provider.")
    invalidation_flow: StrictStr = Field(description="Flow used ending the session from a provider.")
    property_mappings: Optional[List[StrictStr]] = None
    acs_url: Annotated[str, Field(min_length=1, strict=True, max_length=200)]
    audience: Optional[StrictStr] = Field(default=None, description="Value of the audience restriction field of the assertion. When left empty, no audience restriction will be added.")
    issuer: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Also known as EntityID")
    assertion_valid_not_before: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Assertion valid not before current time + this value (Format: hours=-1;minutes=-2;seconds=-3).")
    assertion_valid_not_on_or_after: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Assertion not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).")
    session_valid_not_on_or_after: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Session not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).")
    name_id_mapping: Optional[StrictStr] = Field(default=None, description="Configure how the NameID value will be created. When left empty, the NameIDPolicy of the incoming request will be considered")
    digest_algorithm: Optional[DigestAlgorithmEnum] = None
    signature_algorithm: Optional[SignatureAlgorithmEnum] = None
    signing_kp: Optional[StrictStr] = Field(default=None, description="Keypair used to sign outgoing Responses going to the Service Provider.")
    verification_kp: Optional[StrictStr] = Field(default=None, description="When selected, incoming assertion's Signatures will be validated against this certificate. To allow unsigned Requests, leave on default.")
    encryption_kp: Optional[StrictStr] = Field(default=None, description="When selected, incoming assertions are encrypted by the IdP using the public key of the encryption keypair. The assertion is decrypted by the SP using the the private key.")
    sign_assertion: Optional[StrictBool] = None
    sign_response: Optional[StrictBool] = None
    sp_binding: Optional[SpBindingEnum] = Field(default=None, description="This determines how authentik sends the response back to the Service Provider.")
    default_relay_state: Optional[StrictStr] = Field(default=None, description="Default relay_state value for IDP-initiated logins")
    __properties: ClassVar[List[str]] = ["name", "authentication_flow", "authorization_flow", "invalidation_flow", "property_mappings", "acs_url", "audience", "issuer", "assertion_valid_not_before", "assertion_valid_not_on_or_after", "session_valid_not_on_or_after", "name_id_mapping", "digest_algorithm", "signature_algorithm", "signing_kp", "verification_kp", "encryption_kp", "sign_assertion", "sign_response", "sp_binding", "default_relay_state"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SAMLProviderRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if authentication_flow (nullable) is None
        # and model_fields_set contains the field
        if self.authentication_flow is None and "authentication_flow" in self.model_fields_set:
            _dict['authentication_flow'] = None

        # set to None if name_id_mapping (nullable) is None
        # and model_fields_set contains the field
        if self.name_id_mapping is None and "name_id_mapping" in self.model_fields_set:
            _dict['name_id_mapping'] = None

        # set to None if signing_kp (nullable) is None
        # and model_fields_set contains the field
        if self.signing_kp is None and "signing_kp" in self.model_fields_set:
            _dict['signing_kp'] = None

        # set to None if verification_kp (nullable) is None
        # and model_fields_set contains the field
        if self.verification_kp is None and "verification_kp" in self.model_fields_set:
            _dict['verification_kp'] = None

        # set to None if encryption_kp (nullable) is None
        # and model_fields_set contains the field
        if self.encryption_kp is None and "encryption_kp" in self.model_fields_set:
            _dict['encryption_kp'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SAMLProviderRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "authentication_flow": obj.get("authentication_flow"),
            "authorization_flow": obj.get("authorization_flow"),
            "invalidation_flow": obj.get("invalidation_flow"),
            "property_mappings": obj.get("property_mappings"),
            "acs_url": obj.get("acs_url"),
            "audience": obj.get("audience"),
            "issuer": obj.get("issuer"),
            "assertion_valid_not_before": obj.get("assertion_valid_not_before"),
            "assertion_valid_not_on_or_after": obj.get("assertion_valid_not_on_or_after"),
            "session_valid_not_on_or_after": obj.get("session_valid_not_on_or_after"),
            "name_id_mapping": obj.get("name_id_mapping"),
            "digest_algorithm": obj.get("digest_algorithm"),
            "signature_algorithm": obj.get("signature_algorithm"),
            "signing_kp": obj.get("signing_kp"),
            "verification_kp": obj.get("verification_kp"),
            "encryption_kp": obj.get("encryption_kp"),
            "sign_assertion": obj.get("sign_assertion"),
            "sign_response": obj.get("sign_response"),
            "sp_binding": obj.get("sp_binding"),
            "default_relay_state": obj.get("default_relay_state")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.flow_challenge_response_request import FlowChallengeResponseRequest

class TestFlowChallengeResponseRequest(unittest.TestCase):
    """FlowChallengeResponseRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowChallengeResponseRequest:
        """Test FlowChallengeResponseRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowChallengeResponseRequest`
        """
        model = FlowChallengeResponseRequest()
        if include_optional:
            return FlowChallengeResponseRequest(
                component = 'ak-stage-user-login',
                code = '0',
                email = '0',
                phone_number = '0',
                selected_challenge = authentik_client.models.device_challenge_request.DeviceChallengeRequest(
                    device_class = '0', 
                    device_uid = '0', 
                    challenge = {
                        'key' : null
                        }, 
                    last_used = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                selected_stage = '0',
                webauthn = {
                    'key' : None
                    },
                duo = 56,
                response = {
                    'key' : None
                    },
                token = '0',
                uid_field = '0',
                password = '0',
                captcha_token = '',
                to = '0',
                remember_me = True
            )
        else:
            return FlowChallengeResponseRequest(
                code = '0',
                response = {
                    'key' : None
                    },
                token = '0',
                uid_field = '0',
                password = '0',
                to = '0',
                remember_me = True,
        )
        """

    def testFlowChallengeResponseRequest(self):
        """Test FlowChallengeResponseRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
